Signer Wrapper
==============

Set of signing wrappers which wraps functionality of pubtools-sign projects and provides extra methods needed for the signign process.

.. py:module:: pubtools._quay.signer_wrapper

.. autoclass:: MsgSignerSettingsSchema
    :members:

.. autoclass:: SignerWrapper
    :members:

.. autoclass:: MsgSignerWrapper
    :members:

.. autoclass:: CosignSignerSettingsSchema
    :members:

.. autoclass:: CosignSignerWrapper
